Changelog
---------

1.0.0
-----

* Change game play to be Multiplayer
* Change game to finish when CPU or Player1 wins or use CTRL+C
* Refactor language to be central
* Create Custom exceptions
* Use Python Click to print the board using colors
* Use Python Click to improve the main function

0.3.13
------

* BugFix: Exit game with CTRL+C
* Move exception treatment to battlefield.py
* Create more exceptions
* Create a centralized language translator

0.3.12
------

* Improve UI to print statistics


0.3.11
------

* Update Readme

0.3.10
------

* Fix table layout

0.3.9
-----

* Refactor Main: Remove unnecessary code
* Remove duplicated code
* Add translation

0.3.8
-----

* Fix: Readme Pypi

0.3.7
-----

* Fix: Readme Pypi

0.3.6
-----

* Update readme

0.3.5
-----

* Use vertical label in upper case

0.3.4
-----

* Add more status messages

0.3.3
-----

* Fix logical

0.3.1
-----

* Add locale folder to Manifest.in

0.3.0
-----

* Add Gettext/internationalization support

0.2.0
-----

* Bug Fixes
* Improve better UI
* Fix layout
* Change to use letters instead of only numbers

0.1.0 (2019-01-01)
------------------

* initial release
